@@ -450,7 +450,7 @@ class Message:
     Emit message parser
     """
     def _emit_message_parser(self, hfile, cfile, message_type, fields):
-        translations = { 'name'                     : self.name,
+        translations = { 'message'                  : self.name,
                          'service'                  : self.service,
                          'underscore'               : utils.build_underscore_name (self.fullname),
                          'message_type'             : message_type,
@@ -569,7 +569,7 @@ class Message:
         template += (
             ' * @error: return location for error or %NULL.\n'
             ' *\n'
-            ' * Create a new request for the \'${name}\' ${message_type} command in the \'${service}\' service.\n'
+            ' * Parses and returns parameters of the \'${message}\' ${message_type} command in the \'${service}\' service.\n'
             ' *\n'
             ' * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.\n'
             ' */\n'
